summaryrefslogtreecommitdiff
path: root/boost/asio/posix/basic_stream_descriptor.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'boost/asio/posix/basic_stream_descriptor.hpp')
-rw-r--r--boost/asio/posix/basic_stream_descriptor.hpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/boost/asio/posix/basic_stream_descriptor.hpp b/boost/asio/posix/basic_stream_descriptor.hpp
index 4baacb519b..ca88e31159 100644
--- a/boost/asio/posix/basic_stream_descriptor.hpp
+++ b/boost/asio/posix/basic_stream_descriptor.hpp
@@ -17,6 +17,8 @@
#include <boost/asio/detail/config.hpp>
+#if defined(BOOST_ASIO_ENABLE_OLD_SERVICES)
+
#if defined(BOOST_ASIO_HAS_POSIX_STREAM_DESCRIPTOR) \
|| defined(GENERATING_DOCUMENTATION)
@@ -50,10 +52,6 @@ class basic_stream_descriptor
: public basic_descriptor<StreamDescriptorService>
{
public:
- /// (Deprecated: Use native_handle_type.) The native representation of a
- /// descriptor.
- typedef typename StreamDescriptorService::native_handle_type native_type;
-
/// The native representation of a descriptor.
typedef typename StreamDescriptorService::native_handle_type
native_handle_type;
@@ -64,12 +62,12 @@ public:
* descriptor needs to be opened and then connected or accepted before data
* can be sent or received on it.
*
* @param io_service The io_service object that the stream descriptor will
* use to dispatch handlers for any asynchronous operations performed on the
* descriptor.
*/
- explicit basic_stream_descriptor(boost::asio::io_service& io_service)
- : basic_descriptor<StreamDescriptorService>(io_service)
+ explicit basic_stream_descriptor(boost::asio::io_context& io_context)
+ : basic_descriptor<StreamDescriptorService>(io_context)
{
}
@@ -78,7 +76,7 @@ public:
* This constructor creates a stream descriptor object to hold an existing
* native descriptor.
*
* @param io_service The io_service object that the stream descriptor will
* use to dispatch handlers for any asynchronous operations performed on the
* descriptor.
*
@@ -86,9 +84,9 @@ public:
*
* @throws boost::system::system_error Thrown on failure.
*/
- basic_stream_descriptor(boost::asio::io_service& io_service,
+ basic_stream_descriptor(boost::asio::io_context& io_context,
const native_handle_type& native_descriptor)
- : basic_descriptor<StreamDescriptorService>(io_service, native_descriptor)
+ : basic_descriptor<StreamDescriptorService>(io_context, native_descriptor)
{
}
@@ -101,7 +99,7 @@ public:
* will occur.
*
* @note Following the move, the moved-from object is in the same state as if
* constructed using the @c basic_stream_descriptor(io_service&) constructor.
*/
basic_stream_descriptor(basic_stream_descriptor&& other)
: basic_descriptor<StreamDescriptorService>(
@@ -118,7 +116,7 @@ public:
* will occur.
*
* @note Following the move, the moved-from object is in the same state as if
* constructed using the @c basic_stream_descriptor(io_service&) constructor.
*/
basic_stream_descriptor& operator=(basic_stream_descriptor&& other)
{
@@ -209,7 +207,7 @@ public:
* Regardless of whether the asynchronous operation completes immediately or
* not, the handler will not be invoked from within this function. Invocation
* of the handler will be performed in a manner equivalent to using
- * boost::asio::io_service::post().
+ * boost::asio::io_context::post().
*
* @note The write operation may not transmit all of the data to the peer.
* Consider using the @ref async_write function if you need to ensure that all
@@ -321,7 +319,7 @@ public:
* Regardless of whether the asynchronous operation completes immediately or
* not, the handler will not be invoked from within this function. Invocation
* of the handler will be performed in a manner equivalent to using
- * boost::asio::io_service::post().
+ * boost::asio::io_context::post().
*
* @note The read operation may not read all of the requested number of bytes.
* Consider using the @ref async_read function if you need to ensure that the
@@ -361,4 +359,6 @@ public:
#endif // defined(BOOST_ASIO_HAS_POSIX_STREAM_DESCRIPTOR)
// || defined(GENERATING_DOCUMENTATION)
+#endif // defined(BOOST_ASIO_ENABLE_OLD_SERVICES)
+
#endif // BOOST_ASIO_POSIX_BASIC_STREAM_DESCRIPTOR_HPP
@@ -64,12 +62,12 @@ public:
* can be sent or received on it.
*
- * @param io_service The io_service object that the stream descriptor will
+ * @param io_context The io_context object that the stream descriptor will
* use to dispatch handlers for any asynchronous operations performed on the
* descriptor.
@@ -78,7 +76,7 @@ public:
* native descriptor.
*
- * @param io_service The io_service object that the stream descriptor will
+ * @param io_context The io_context object that the stream descriptor will
* use to dispatch handlers for any asynchronous operations performed on the
* descriptor.
@@ -101,7 +99,7 @@ public:
*
* @note Following the move, the moved-from object is in the same state as if
- * constructed using the @c basic_stream_descriptor(io_service&) constructor.
+ * constructed using the @c basic_stream_descriptor(io_context&) constructor.
*/
basic_stream_descriptor(basic_stream_descriptor&& other)
@@ -118,7 +116,7 @@ public:
*
* @note Following the move, the moved-from object is in the same state as if
- * constructed using the @c basic_stream_descriptor(io_service&) constructor.
+ * constructed using the @c basic_stream_descriptor(io_context&) constructor.
*/
basic_stream_descriptor& operator=(basic_stream_descriptor&& other)